@@ -7,7 +7,7 @@ from __future__ import annotations
 
 from . import time, zones
 
-from .explore import Action, Destination, Transition, State, Explorer
+from .explore import Action, Destination, Transition, State, Explorer, Parameters
 from .time import TimeType, DiscreteTime
 from .values import Value
 
@@ -18,6 +18,7 @@ __all__ = [
     "Transition",
     "State",
     "Explorer",
+    "Parameters",
     "TimeType",
     "DiscreteTime",
     "Value",
