@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Copyright (C) 2019, Maximilian Köhl <mkoehl@cs.uni-saarland.de>
+# Copyright (C) 2019-2020, Maximilian Köhl <koehl@cs.uni-saarland.de>
 
 from __future__ import annotations
 
@@ -9,7 +9,7 @@ import typing as t
 import functools
 
 
-T = t.TypeVar('T')
+T = t.TypeVar("T")
 
 
 # XXX: this is here just to make `mypy` happy
